@@ -2,7 +2,7 @@ from dataflows import Flow, concatenate, add_computed_field, \
     unpivot, set_primary_key, PackageWrapper, set_type
 from dataflows.base.schema_validator import ignore
 
-from ...core import BaseDataGenusProcessor, Validator, Required
+from ...core import BaseDataGenusProcessor
 from .analyzers import TaxonomiesDGP, MappingDGP
 from ...config.consts import CONFIG_MODEL_EXTRA_FIELDS, CONFIG_MODEL_MAPPING,\
             CONFIG_TAXONOMY_CT, CONFIG_CONSTANTS, RESOURCE_NAME, CONFIG_PRIMARY_KEY
